---
name: Feature Request
about: Suggest improvements to F´
title: ''
labels: enhancement
assignees: ''

---

| | |
|:---|:---|
|**_F´ Version_**| |
|**_Affected Component_**|  |
---
## Feature Description

A quick description of the requested feature.

## Rationale

A rationale for why the feature should be implemented in F´.
